@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Callable, Iterator
+from typing import TYPE_CHECKING, Callable
 
 import pytest
 
@@ -8,6 +8,7 @@ from pipdeptree._models.dag import PackageDAG
 from pipdeptree._render.json_tree import render_json_tree
 
 if TYPE_CHECKING:
+    from collections.abc import Iterator
     from unittest.mock import Mock
 
     from tests.our_types import MockGraph
@@ -25,7 +26,7 @@ def test_json_tree_given_req_package_with_version_spec(
     version_spec_tuple: tuple[str, str],
     expected_version_spec: str,
 ) -> None:
-    graph: dict[tuple[str, str], list[tuple[str, list[tuple[str, str]]]]] = {
+    graph: MockGraph = {
         ("a", "1.2.3"): [("b", [version_spec_tuple])],
         ("b", "2.2.0"): [],
     }
